@@ -3,6 +3,8 @@ package Config::Any::JSON;
 use strict;
 use warnings;
 
+use base 'Config::Any::Base';
+
 =head1 NAME
 
 Config::Any::JSON - Load JSON config files
@@ -48,26 +50,32 @@ sub load {
     close $fh;
 
     eval { require JSON::Syck; };
-    if( $@ ) {
+    if ( $@ ) {
         require JSON;
-        return JSON::jsonToObj( $content );
+        eval { JSON->VERSION( 2 ); };
+        return $@ ? JSON::jsonToObj( $content ) : JSON::from_json( $content );
     }
     else {
         return JSON::Syck::Load( $content );
     }
 }
 
+=head2 requires_any_of( )
+
+Specifies that this modules requires one of L<JSON::Syck> or L<JSON> in 
+order to work.
+
+=cut
+
+sub requires_any_of { 'JSON::Syck', 'JSON' }
+
 =head1 AUTHOR
 
-=over 4 
-
-=item * Brian Cassidy E<lt>bricas@cpan.orgE<gt>
-
-=back
+Brian Cassidy E<lt>bricas@cpan.orgE<gt>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright 2006 by Brian Cassidy
+Copyright 2007 by Brian Cassidy
 
 This library is free software; you can redistribute it and/or modify
 it under the same terms as Perl itself. 
